## Quick start

To use it, add this to your `gramex.yaml`:

    import:
      ui:
        path: $GRAMEXAPPS/ui/gramex.yaml    # Import the UI components
        YAMLURL: $YAMLURL/ui/               # ... at this URL

Then include this in your HTML:

    <link rel="stylesheet" href="ui/bootstraptheme.css">

    <script src="ui/jquery/dist/jquery.min.js"></script>
    <script src="ui/bootstrap/dist/js/bootstrap.bundle.min.js"></script>